@@ -2,8 +2,8 @@
  * lib.c - etsh library routines
  */
 /*-
- * Copyright (c) 2004-2018
- *	Jeffrey Allen Neitzel <jan (at) etsh (dot) io>.
+ * Copyright (c) 2004-2019
+ *	Jeffrey Allen Neitzel <jan (at) etsh (dot) nl>.
  *	All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: lib.c,v 1.1 2018/06/14 00:00:00 jneitzel $
+ *	@(#)$Id: lib.c,v 1.7 2019/03/18 06:54:50 jneitzel Exp $
  */
 /*-
  * Copyright (C) Caldera International Inc.  2001-2002.  All rights reserved.
@@ -73,7 +73,6 @@
  */
 static	const char	**gavp;	 /* points to current gav position     */
 static	const char	**gave;	 /* points to current gav end          */
-static	unsigned	gavmult; /* GAVNEW reallocation multiplier     */
 static	size_t		gavtot;	 /* total bytes used for all arguments */
 
 /*
@@ -81,14 +80,14 @@ static	size_t		gavtot;	 /* total bytes used for all arguments */
  */
 static	void		prompt_debug(const char *);
 /*@null@*/
-static	char		*gtrim(/*@returned@*/ UChar *);
+static	char		*gtrim(/*@returned@*/ u_char *);
 static	const char	**gnew(/*@only@*/ const char **);
 /*@null@*/
 static	char		*gcat(/*@null@*/ const char *,
 			      /*@null@*/ const char *, bool);
 static	const char	**glob1(enum sbikey, /*@only@*/ const char **,
 				char *, int *, bool *);
-static	bool		glob2(const UChar *, const UChar *);
+static	bool		glob2(const u_char *, const u_char *);
 static	void		gsort(const char **);
 /*@null@*/
 static	DIR		*gopendir(/*@out@*/ char *, const char *);
@@ -99,7 +98,7 @@ static	DIR		*gopendir(/*@out@*/ char *, const char *);
 void
 error(int s, const char *m)
 {
-	long ln;
+	long int ln;
 
 	if (m == NULL) {
 		sh_err(ESTATUS, FMT3S, getmyname(), __func__, strerror(EINVAL));
@@ -126,7 +125,7 @@ error(int s, const char *m)
 void
 error1(int s, const char *f, const char *m)
 {
-	long ln;
+	long int ln;
 
 	if (f == NULL || m == NULL) {
 		sh_err(ESTATUS, FMT3S, getmyname(), __func__, strerror(EINVAL));
@@ -153,7 +152,7 @@ error1(int s, const char *f, const char *m)
 void
 error2(int s, const char *c, const char *a, const char *m)
 {
-	long ln;
+	long int ln;
 
 	if (c == NULL || a == NULL || m == NULL) {
 		sh_err(ESTATUS, FMT3S, getmyname(), __func__, strerror(EINVAL));
@@ -290,7 +289,7 @@ prompt_write(void)
 		else {
 			(void)memset(&buf, 0, sizeof(buf));
 			pcp = memcpy(buf, p, strlen(p) + 1);
-			ptp = atrim(UCPTR(pcp), true);
+			ptp = atrim(U_CPTR(pcp), true);
 			if (prompt_dbg) /* dbg == debug in spirit =^) */
 				prompt_debug(ptp);
 			fd_print(FD2, "%s", ptp);
@@ -305,7 +304,7 @@ static void
 prompt_debug(const char *ptp)
 {
 	const char *pdp;
-	unsigned cnt;
+	u_int cnt;
 
 	fd_print(FD1, "\n\"quoted\" printable $P string:\n");
 	fd_print(FD1, "\t\"");
@@ -339,22 +338,22 @@ prompt_debug(const char *ptp)
  * equivalent literals.
  */
 char *
-atrim(UChar *ap, bool pe /* prompt escape */)
+atrim(u_char *ap, bool pe /* prompt escape */)
 {
 	size_t siz;
-	UChar *a, *b;
-	UChar buf[_LINESIZ], c;
+	u_char *a, *b;
+	u_char buf[_LINESIZ], c;
 	const char *em;
 	bool d;
 
 	if (ap == NULL)
 		goto aterr;
 
-	*buf = UCHAR(EOS);
+	*buf = U_CHAR(EOS);
 	for (a = ap, b = buf; b < &buf[_LINESIZ]; a++, b++) {
 		switch (*a) {
 		case EOS:
-			*b = UCHAR(EOS);
+			*b = U_CHAR(EOS);
 			siz = (b - buf) + 1;
 			(void)memcpy(ap, buf, siz);
 			return (char *)ap;
@@ -379,15 +378,15 @@ atrim(UChar *ap, bool pe /* prompt escape */)
 				break;
 			case 'a':
 				if (!pe) break;
-				*b = UCHAR(BEL);
+				*b = U_CHAR(BEL);
 				continue;
 			case 'n':
 				if (!pe) break;
-				*b = UCHAR(EOL);
+				*b = U_CHAR(EOL);
 				continue;
 			case 't':
 				if (!pe) break;
-				*b = UCHAR(TAB);
+				*b = U_CHAR(TAB);
 				continue;
 			}
 			break;
@@ -398,7 +397,7 @@ atrim(UChar *ap, bool pe /* prompt escape */)
 aterr:
 	if (ap == NULL) {
 		em = strerror(EINVAL);
-		ap = UCPTR("");
+		ap = U_CPTR("");
 	} else
 		em = ERR_TRIM;
 	error(-1, em);
@@ -417,18 +416,18 @@ aterr:
  * This function returns NULL on error.
  */
 static char *
-gtrim(UChar *ap)
+gtrim(u_char *ap)
 {
 	size_t siz;
-	UChar *a, *b, *nap;
-	UChar buf[PATHMAX], c;
+	u_char *a, *b, *nap;
+	u_char buf[PATHMAX], c;
 	bool d;
 
-	*buf = UCHAR(EOS);
+	*buf = U_CHAR(EOS);
 	for (a = ap, b = buf; b < &buf[PATHMAX]; a++, b++) {
 		switch (*a) {
 		case EOS:
-			*b = UCHAR(EOS);
+			*b = U_CHAR(EOS);
 			siz = (b - buf) + 1;
 			nap = ap;
 			if (siz > strlen((const char *)ap) + 1) {
@@ -450,7 +449,7 @@ gtrim(UChar *ap)
 				case ASTERISK: case QUESTION:
 				case LBRACKET: case RBRACKET: case HYPHEN:
 				case DQUOT:    case SQUOT:
-					*b = UCHAR(BQUOT);
+					*b = U_CHAR(BQUOT);
 					if (++b >= &buf[PATHMAX])
 						goto gterr;
 					break;
@@ -467,7 +466,7 @@ gtrim(UChar *ap)
 			case ASTERISK: case QUESTION:
 			case LBRACKET: case RBRACKET: case HYPHEN:
 			case DQUOT:    case SQUOT:    case BQUOT:
-				*b = UCHAR(BQUOT);
+				*b = U_CHAR(BQUOT);
 				if (++b >= &buf[PATHMAX])
 					goto gterr;
 				break;
@@ -528,8 +527,7 @@ glob(enum sbikey key, char **av)
 	int pmc = 0;		/* pattern match count                 */
 	bool gerr = false;	/* glob error flag                     */
 
-	gavmult = 1;
-	gavtot  = 0;
+	gavtot = 0;
 
 	oav  = av;
 	gav  = xmalloc(GAVNEW * sizeof(char *));
@@ -537,7 +535,7 @@ glob(enum sbikey key, char **av)
 	gavp = gav;
 	gave = &gav[GAVNEW - 1];
 	while (*av != NULL) {
-		if ((tpap = gtrim(UCPTR(*av))) == NULL) {
+		if ((tpap = gtrim(U_CPTR(*av))) == NULL) {
 			*gavp = NULL;
 			gerr  = true;
 			break;
@@ -568,25 +566,24 @@ gnew(const char **gav)
 {
 	size_t siz;
 	ptrdiff_t gidx;
+	const char **nav;
+	static unsigned int mult = 1; /* GAVNEW reallocation multiplier */
 
 	if (gavp == gave) {
-		gavmult *= GAVMULT;
-#ifdef	DEBUG
+		mult *= GAVMULT;
 #ifdef	DEBUG_GLOB
-		fd_print(FD2, "%s: gavmult == %u;\n", __func__, gavmult);
-#endif
+		fd_print(FD2, "%s: mult == %u;\n", __func__, mult);
 #endif
 		gidx = (ptrdiff_t)(gavp - gav);
-		siz  = (size_t)((gidx + (GAVNEW * gavmult)) * sizeof(char *));
-#ifdef	DEBUG
+		siz  = (size_t)((gidx + (GAVNEW * mult)) * sizeof(char *));
 #ifdef	DEBUG_GLOB
-		fd_print(FD2, "    : (GAVNEW * gavmult) == %u, siz == %zu;\n",
-		    (GAVNEW * gavmult), siz);
+		fd_print(FD2, "    : (GAVNEW * mult) == %u, siz == %zu;\n",
+		    (GAVNEW * mult), siz);
 #endif
-#endif
-		gav  = xrealloc(gav, siz);
+		nav  = xrealloc(gav, siz);
+		gav  = nav;
 		gavp = gav + gidx;
-		gave = &gav[gidx + (GAVNEW * gavmult) - 1];
+		gave = &gav[gidx + (GAVNEW * mult) - 1];
 	}
 	return gav;
 }
@@ -632,13 +629,11 @@ gcat(const char *src1, const char *src2, bool slash)
 		error(-2, ERR_E2BIG);
 		return NULL;
 	}
-#ifdef	DEBUG
 #ifdef	DEBUG_GLOB
 	fd_print(FD2, "%s: siz == %zu, (%p < %p) == %s;\n", __func__,
 	    siz, (void *)b, (void *)&buf[PATHMAX],
 	    (b < &buf[PATHMAX]) ? "true" : "false");
 	fd_print(FD2, "    : strlen(buf) == %zu;\n", strlen(buf));
-#endif
 #endif
 	dst = xmalloc(siz);
 
@@ -661,7 +656,7 @@ glob1(enum sbikey key, const char **gav, char *as, int *pmc, bool *gerr)
 	if ((ps = gchar(as)) == NULL) {
 		gav = gnew(gav);
 		if (DO_TRIM(key))
-			(void)atrim(UCPTR(as), false);
+			(void)atrim(U_CPTR(as), false);
 		if ((p = gcat(as, "", slash)) == NULL) {
 			*gavp = NULL;
 			*gerr = true;
@@ -698,7 +693,7 @@ glob1(enum sbikey key, const char **gav, char *as, int *pmc, bool *gerr)
 	while ((entry = readdir(dirp)) != NULL) {
 		if (entry->d_name[0] == DOT && *ps != DOT)
 			continue;
-		if (glob2(UCPTR(entry->d_name), UCPTR(ps))) {
+		if (glob2(U_CPTR(entry->d_name), U_CPTR(ps))) {
 			gav = gnew(gav);
 			if ((p = gcat(ds, entry->d_name, slash)) == NULL) {
 				(void)closedir(dirp);
@@ -718,11 +713,11 @@ glob1(enum sbikey key, const char **gav, char *as, int *pmc, bool *gerr)
 }
 
 static bool
-glob2(const UChar *ename, const UChar *pattern)
+glob2(const u_char *ename, const u_char *pattern)
 {
 	int cok, rok;		/* `[...]' - cok (class), rok (range) */
-	UChar c, ec, pc;
-	const UChar *e, *n, *p;
+	u_char c, ec, pc;
+	const u_char *e, *n, *p;
 
 	e = ename;
 	p = pattern;
@@ -755,7 +750,7 @@ glob2(const UChar *ename, const UChar *pattern)
 	case LBRACKET:
 		if (*p == EOS)
 			break;
-		for (c = UCHAR(EOS), cok = rok = 0, n = p + 1; ; ) {
+		for (c = U_CHAR(EOS), cok = rok = 0, n = p + 1; ; ) {
 			pc = *p++;
 			if (pc == RBRACKET && p > n) {
 				if (cok > 0 || rok > 0)
@@ -773,7 +768,7 @@ glob2(const UChar *ename, const UChar *pattern)
 					rok++;
 				else if (c == ec)
 					cok--;
-				c = UCHAR(EOS);
+				c = U_CHAR(EOS);
 			} else {
 				if (pc == BQUOT) {
 					pc = *p++;
@@ -825,7 +820,7 @@ gopendir(char *buf, const char *dname)
 
 	for (*buf = EOS, b = buf, d = dname; b < &buf[PATHMAX]; b++, d++)
 		if ((*b = *d) == EOS) {
-			(void)atrim(UCPTR(buf), false);
+			(void)atrim(U_CPTR(buf), false);
 			break;
 		}
 	return (b >= &buf[PATHMAX]) ? NULL : opendir(buf);
