@@ -1,10 +1,10 @@
 /*
- * etsh - an   enhanced port of the Sixth Edition (V6) UNIX Thompson shell
- *  tsh - an unenhanced port of the Sixth Edition (V6) UNIX Thompson shell
+ * etsh - an   enhanced port of the Version 6 (V6) Thompson shell
+ *  tsh - an unenhanced port of the Version 6 (V6) Thompson shell
  */
 /*-
- * Copyright (c) 2004-2018
- *	Jeffrey Allen Neitzel <jan (at) etsh (dot) io>.
+ * Copyright (c) 2004-2019
+ *	Jeffrey Allen Neitzel <jan (at) etsh (dot) nl>.
  *	All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: sh_err.h,v 1.1 2018/06/14 00:00:00 jneitzel $
+ *	@(#)$Id: sh_err.h,v 1.5 2019/01/12 23:34:36 jneitzel Exp $
  */
 
 #ifndef	SH_ERR_H
@@ -79,6 +79,7 @@
 #define	ERR_GENERIC	"error"
 #define	ERR_LABNOTFOUND	"label not found"
 #define	ERR_LABTOOLONG	"label too long"
+#define	ERR_TOOLARGE	"too large"
 #define	ERR_NOARGS	"no args"
 #define	ERR_NOTFOUND	"not found"
 #define	ERR_RANGE	"out of range"
@@ -92,9 +93,12 @@
 #define	ERR_OPERATOR	"operator expected"
 #define	ERR_BRACE	"} expected"
 #define	ERR_OPUNKNOWN	"unknown operator"
+
+#define	PWD_USAGE	"usage: %s\n"
 #define	FD2_USAGE	"usage: %s [-e] [-f file] [--] command [arg ...]\n"
 #define	ETSH_USAGE	"usage: %s [-V | -VV]\n       %s [-nv] [- | -c [string] | -i | -l | -t | file [arg1 ...]]\n"
-#define	ETSH_VNUM_URL	"etsh %s ( %s )\n"
+#define	ETSH_VERSION_URL\
+			"%s ( %s )\n\n"
 #define	PROMPT_USAGE	"usage: prompt [on | debug | off]\n"
 #define	VERBOSE_USAGE	"usage: verbose [true | false]\n"
 
