@@ -2,8 +2,8 @@
  * util.c - special built-in shell utilities for etsh
  */
 /*-
- * Copyright (c) 2004-2018
- *	Jeffrey Allen Neitzel <jan (at) etsh (dot) io>.
+ * Copyright (c) 2004-2019
+ *	Jeffrey Allen Neitzel <jan (at) etsh (dot) nl>.
  *	All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: util.c,v 1.1 2018/06/14 00:00:00 jneitzel $
+ *	@(#)$Id: util.c,v 1.10 2019/03/18 00:56:29 jneitzel Exp $
  */
 /*
  *	Derived from:
@@ -67,6 +67,46 @@
  * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
+/*
+ * The following license covers the documentation for the
+ * sbi_pwd() function:
+ */
+/*-
+ *	$OpenBSD: pwd.1,v 1.21 2014/05/28 14:16:27 jmc Exp $
+ *	$NetBSD: pwd.1,v 1.10 1995/09/07 06:47:30 jtc Exp $
+ *
+ *  Copyright (c) 1990, 1993
+ *	The Regents of the University of California.  All rights reserved.
+ *
+ *  This code is derived from software contributed to Berkeley by
+ *  the Institute of Electrical and Electronics Engineers, Inc.
+ *
+ *  Redistribution and use in source and binary forms, with or without
+ *  modification, are permitted provided that the following conditions
+ *  are met:
+ *  1. Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *  2. Redistributions in binary form must reproduce the above copyright
+ *     notice, this list of conditions and the following disclaimer in the
+ *     documentation and/or other materials provided with the distribution.
+ *  3. Neither the name of the University nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ *  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ *  SUCH DAMAGE.
+ *
+ *      @(#)pwd.1	8.2 (Berkeley) 4/28/95
+ */
 
 #define	ETSH_SHELL
 
@@ -77,7 +117,7 @@
 #include "strtoint.h"
 
 #define	IS_SBI(k)	\
-	((k) == SBI_ECHO || (k) == SBI_FD2 || (k) == SBI_GOTO || (k) == SBI_IF)
+	((k) == SBI_ECHO || (k) == SBI_FD2 || (k) == SBI_GOTO || (k) == SBI_IF || (k) == SBI_PWD)
 
 static	int	sbi_echo(int, char **);
 /*@maynotreturn@*/
@@ -86,6 +126,7 @@ static	int	sbi_fd2(int, char **);
 static	int	sbi_goto(int, char **);
 /*@maynotreturn@*/
 static	int	sbi_if(int, char **);
+static	int	sbi_pwd(int, char **);
 
 /*
  * Execute the shell utility specified by key w/ the argument
@@ -108,6 +149,7 @@ uexec(enum sbikey key, int ac, char **av)
 	case SBI_FD2:	util = &sbi_fd2;	break;
 	case SBI_GOTO:	util = &sbi_goto;	break;
 	case SBI_IF:	util = &sbi_if;		break;
+	case SBI_PWD:	util = &sbi_pwd;	break;
 	default:
 		sh_err(FC_ERR, FMT3S, getmyname(), __func__, "Invalid utility");
 		/*NOTREACHED*/
@@ -121,11 +163,9 @@ uexec(enum sbikey key, int ac, char **av)
 	if (cnt-- > cnt1)
 		s = r;
 
-#ifdef	DEBUG
 #ifdef	DEBUG_PROC
 	if (cnt == 0)
 		fd_print(FD2, "%s: return %d;\n", __func__, s);
-#endif
 #endif
 
 	return s;
@@ -269,7 +309,7 @@ sbi_goto(int argc, char **argv)
 	if (lseek(FD0, (off_t)0, SEEK_SET) == -1)
 		sh_err(FC_ERR, FMT2S, getmyname(), ERR_SEEK);
 
-	while (getlabel(label, UCHAR(*argv[1] & 0377), siz))
+	while (getlabel(label, U_CHAR(*argv[1] & 0377), siz))
 		if (strcmp(label, argv[1]) == 0) {
 			(void)lseek(FD0, offset, SEEK_SET);
 			return SH_TRUE;
@@ -350,7 +390,7 @@ xgetc(void)
 	offset++;
 	nc = getchar();
 	if (nc != EOF) {
-		nc = UCHAR(nc & 0377);
+		nc = U_CHAR(nc & 0377);
 		return nc;
 	}
 	return EOF;
@@ -446,7 +486,7 @@ e3(void)
 {
 	bool re;
 	pid_t cpid, tpid;
-	long ai, ci;
+	long int ai, ci;
 	int cstat, d;
 	char *a, *b, *c;
 
@@ -733,3 +773,44 @@ equal(const char *a, const char *b)
 		return false;
 	return EQUAL(a, b);
 }
+
+/*
+ * NAME
+ *	pwd - print the pathname of the current working directory
+ *
+ * SYNOPSIS
+ *	pwd
+ *
+ * DESCRIPTION
+ *	Pwd prints the absolute physical pathname of the current working
+ *	directory to the standard output.
+ *
+ * EXIT STATUS / RETURN VALUE
+ *	0    The current working directory pathname was successfully printed.
+ *
+ *	2    An error was detected by getcwd(3), or a usage error was
+ *	     detected by pwd itself.
+ */
+static int
+sbi_pwd(int argc, char **argv)
+{
+	char *b, buf[PATHMAX + 1];
+	int   s;
+
+	setmyname(argv[0]);
+
+	if (argc != 1)
+		sh_err(FC_ERR, PWD_USAGE, getmyname());
+
+	b = NULL;
+
+	errno = 0;
+	b = getcwd(buf, sizeof(buf));
+	if (errno != 0)
+		sh_err(FC_ERR, FMT2S, getmyname(), strerror(errno));
+
+	fd_print(FD1, "%s\n", b);
+	s = SH_TRUE;
+
+	return s;
+}
